diff options
| author | Martin Kagamino Lehoux <martin@lehoux.net> | 2025-08-21 22:36:06 +0200 |
|---|---|---|
| committer | Martin Kagamino Lehoux <martin@lehoux.net> | 2025-08-27 11:43:09 +0200 |
| commit | 911f1fe752173fdfee3f135acd2509c908c7fce2 (patch) | |
| tree | 368735cd3f04be789ce7ea47659b8bf81f4d28d7 /README.md | |
| parent | 4936f490ea8f800047bb0601832c9f32e2bc603e (diff) | |
chore: Better benchmark & profiling setup
Diffstat (limited to 'README.md')
| -rw-r--r-- | README.md | 10 |
1 files changed, 7 insertions, 3 deletions
@@ -4,15 +4,19 @@ - Vec_get not safe, I made a type mistake. And should be more efficient for loops - Fix tests in release -- Benchmark 100MB file - - json.loads: 526 ms ± 77 ms per loop (mean ± std. dev. of 7 runs, 1 loop each) - - self: 348 ms (mean of 7 runs, 1 loop each). 2079 MB/s - Static functions for private? - `valgrind --leak-check=full ./your_program` - assert with error msg? - negative numbers - web server, Json parsing, struct codegen +## Benchmarks + +| version | result | +|---|---| +|json.loads|652 ms ± 6.65 ms per loop (mean ± std. dev. of 7 runs, 1 loop each)| +|v1|336 ms ± 163 ms per loop (mean ± std. dev. of 10 runs, 1 loop each)| + ## Resources - https://nullprogram.com/blog/2023/10/08/ |
